@@ -20,28 +20,28 @@ class SVSyncShared(SVSyncBase):
         name = self.getDataName(nid, seqNum)
         while retries+1 > 0:
             try:
-                logging.info(f'SVS_Socket: fetching data {Name.to_str(name)}')
+                logging.info(f'SVSync: fetching data {Name.to_str(name)}')
                 ex_int_name, meta_info, content = await self.app.express_interest(name, must_be_fresh=True, can_be_prefix=False, lifetime=6000)
-                logging.info(f'SVS_Socket: received data {bytes(content)}')
+                logging.info(f'SVSync: received data {bytes(content)}')
                 if content and self.cacheOthers:
                     data_packet = make_data(name, MetaInfo(freshness_period=5000), content=bytes(content))
-                    logging.info(f'SVS_Socket: publishing others data {Name.to_str(name)}')
+                    logging.info(f'SVSync: publishing others data {Name.to_str(name)}')
                     self.storage.put_data_packet(name, data_packet)
                 return bytes(content) if content else None
             except InterestNack as e:
-                logging.warning(f'SVS_Socket: nacked with reason={e.reason}')
+                logging.warning(f'SVSync: nacked with reason={e.reason}')
             except InterestTimeout:
-                logging.warning(f'SVS_Socket: timeout')
+                logging.warning(f'SVSync: timeout')
             except InterestCanceled:
-                logging.warning(f'SVS_Socket: canceled')
+                logging.warning(f'SVSync: canceled')
             except ValidationFailure:
-                logging.warning(f'SVS_Socket: data failed to validate')
+                logging.warning(f'SVSync: data failed to validate')
             except Exception as e:
-                logging.warning(f'SVS_Socket: unknown error has occured: {e}')
+                logging.warning(f'SVSync: unknown error has occured: {e}')
 
             retries = retries - 1
             if retries+1 > 0:
-                logging.warning(f'SVS_Socket: retrying fetching data')
+                logging.warning(f'SVSync: retrying fetching data')
         return None
     def getDataName(self, nid:Name, seqNum:int) -> Name:
         return ( self.groupPrefix + [Component.from_str("d")] + nid + Name.from_str("/epoch-"+str(seqNum)) )
\ No newline at end of file
